[Libreoffice-commits] core.git: 2 commits - sw/inc sw/source

Caolán McNamara caolanm at redhat.com
Fri Mar 24 14:38:01 UTC 2017


 sw/inc/viewsh.hxx                   |    2 -
 sw/source/core/view/vprint.cxx      |    6 ++--
 sw/source/filter/basflt/shellio.cxx |   49 +++++++++++++++++-------------------
 3 files changed, 28 insertions(+), 29 deletions(-)

New commits:
commit cb20ca1f52f2a0d61b972f88fb01e23958a0f3a5
Author: Caolán McNamara <caolanm at redhat.com>
Date:   Fri Mar 24 14:29:35 2017 +0000

    fix indent
    
    Change-Id: Ifc1f654e4f63fc7aa62e1b920d1550281a0fa71e

diff --git a/sw/source/filter/basflt/shellio.cxx b/sw/source/filter/basflt/shellio.cxx
index 642c84dca8de..0dc77c9d5ea2 100644
--- a/sw/source/filter/basflt/shellio.cxx
+++ b/sw/source/filter/basflt/shellio.cxx
@@ -486,37 +486,36 @@ SwDoc* Reader::GetTemplateDoc()
             aChkDateTime += tools::Time( 0L, 1L );
         }
 
-        if( bLoad )
+        if (bLoad)
         {
             ClearTemplate();
             OSL_ENSURE( !mxTemplate.is(), "Who holds the template doc?" );
 
-                // If the writer module is not installed,
-                // we cannot create a SwDocShell. We could create a
-                // SwWebDocShell however, because this exists always
-                // for the help.
-                SvtModuleOptions aModuleOptions;
-                if( aModuleOptions.IsWriter() )
+            // If the writer module is not installed,
+            // we cannot create a SwDocShell. We could create a
+            // SwWebDocShell however, because this exists always
+            // for the help.
+            SvtModuleOptions aModuleOptions;
+            if (aModuleOptions.IsWriter())
+            {
+                SwDocShell *pDocSh = new SwDocShell(SfxObjectCreateMode::INTERNAL);
+                SfxObjectShellLock xDocSh = pDocSh;
+                if (pDocSh->DoInitNew())
                 {
-                    SwDocShell *pDocSh =
-                        new SwDocShell ( SfxObjectCreateMode::INTERNAL );
-                    SfxObjectShellLock xDocSh = pDocSh;
-                    if( pDocSh->DoInitNew() )
-                    {
-                        mxTemplate = pDocSh->GetDoc();
-                        mxTemplate->SetOle2Link( Link<bool,void>() );
-                        // always FALSE
-                        mxTemplate->GetIDocumentUndoRedo().DoUndo( false );
-                        mxTemplate->getIDocumentSettingAccess().set(DocumentSettingId::BROWSE_MODE, bTmplBrowseMode );
-                        mxTemplate->RemoveAllFormatLanguageDependencies();
-
-                        ReadXML->SetOrganizerMode( true );
-                        SfxMedium aMedium( aFileName, StreamMode::NONE );
-                        SwReader aRdr( aMedium, OUString(), mxTemplate.get() );
-                        aRdr.Read( *ReadXML );
-                        ReadXML->SetOrganizerMode( false );
-                    }
+                    mxTemplate = pDocSh->GetDoc();
+                    mxTemplate->SetOle2Link( Link<bool,void>() );
+                    // always FALSE
+                    mxTemplate->GetIDocumentUndoRedo().DoUndo( false );
+                    mxTemplate->getIDocumentSettingAccess().set(DocumentSettingId::BROWSE_MODE, bTmplBrowseMode );
+                    mxTemplate->RemoveAllFormatLanguageDependencies();
+
+                    ReadXML->SetOrganizerMode( true );
+                    SfxMedium aMedium( aFileName, StreamMode::NONE );
+                    SwReader aRdr( aMedium, OUString(), mxTemplate.get() );
+                    aRdr.Read( *ReadXML );
+                    ReadXML->SetOrganizerMode( false );
                 }
+            }
         }
 
         OSL_ENSURE( !mxTemplate.is() || FStatHelper::IsDocument( aFileName ) || aTemplateNm=="$$Dummy$$",
commit a85840ecea45d254c932f011f3f43f307b089f8a
Author: Caolán McNamara <caolanm at redhat.com>
Date:   Fri Mar 24 14:24:09 2017 +0000

    Offst might as well be expanded to Offset
    
    Change-Id: I6ba3131155fbbe5a01e47aca4008d39191254fe0

diff --git a/sw/source/core/view/vprint.cxx b/sw/source/core/view/vprint.cxx
index 110ae57b2bf3..b9f516251d1f 100644
--- a/sw/source/core/view/vprint.cxx
+++ b/sw/source/core/view/vprint.cxx
@@ -200,9 +200,9 @@ void SwViewShell::InitPrt( OutputDevice *pOutDev )
     // physical page while the output uses OutputOffset as origin.
     if ( pOutDev )
     {
-        maPrtOffst = Point();
+        maPrtOffset = Point();
 
-        maPrtOffst += pOutDev->GetMapMode().GetOrigin();
+        maPrtOffset += pOutDev->GetMapMode().GetOrigin();
         MapMode aMapMode( pOutDev->GetMapMode() );
         aMapMode.SetMapUnit( MapUnit::MapTwip );
         pOutDev->SetMapMode( aMapMode );
@@ -210,7 +210,7 @@ void SwViewShell::InitPrt( OutputDevice *pOutDev )
         pOutDev->SetFillColor();
     }
     else
-        maPrtOffst.X() = maPrtOffst.Y() = 0;
+        maPrtOffset.X() = maPrtOffset.Y() = 0;
 
     if ( !mpWin )
         mpOut = pOutDev;


More information about the Libreoffice-commits mailing list
diff --git a/sw/inc/viewsh.hxx b/sw/inc/viewsh.hxx
index fd3d28132e7c..965d98697f20 100644
--- a/sw/inc/viewsh.hxx
+++ b/sw/inc/viewsh.hxx
@@ -113,7 +113,7 @@ class SW_DLLPUBLIC SwViewShell : public sw::Ring<SwViewShell>
                                      // i.e. if the EndActions of the other
                                      // Shells on the document are through.
 
-    Point         maPrtOffst;        // Ofst for Printer,
+    Point         maPrtOffset;       // Offset for Printer,
                                      // non-printable margin.
     Size          maBrowseBorder;    // Border for frame documents.
     SwRect        maInvalidRect;